@@ -49,6 +49,9 @@ struct _KatzeItem
 struct _KatzeItemClass
 {
     GObjectClass parent_class;
+
+    gpointer
+    (*copy)                       (KatzeItem*      item);
 };
 
 GType
@@ -106,6 +109,9 @@ void
 katze_item_set_parent             (KatzeItem*      item,
                                    gpointer        parent);
 
+KatzeItem*
+katze_item_copy                   (KatzeItem*      item);
+
 G_END_DECLS
 
 #endif /* __MIDORI_WEB_ITEM_H__ */
