@@ -61,13 +61,19 @@ katze_net_object_maybe_unref (gpointer object)
 static void
 katze_net_init (KatzeNet* net)
 {
+    #if HAVE_LIBSOUP
+    static SoupSession* session = NULL;
+    #endif
+
     net->memory = g_hash_table_new_full (g_str_hash, g_str_equal,
                                          g_free, katze_net_object_maybe_unref);
     net->cache_path = g_build_filename (g_get_user_cache_dir (),
                                         PACKAGE_NAME, NULL);
 
     #if HAVE_LIBSOUP
-    net->session = soup_session_async_new ();
+    if (!session)
+        session = soup_session_async_new ();
+    net->session = session;
     #endif
 }
 
@@ -85,21 +91,48 @@ katze_net_finalize (GObject* object)
 /**
  * katze_net_new:
  *
- * Instantiates a new #KatzeNet singleton.
- *
- * Subsequent calls will ref the initial instance.
+ * Instantiates a new #KatzeNet instance.
  *
  * Return value: a new #KatzeNet
  **/
 KatzeNet*
 katze_net_new (void)
 {
-    KatzeNet* net = g_object_new (KATZE_TYPE_NET,
-                                  NULL);
+    static KatzeNet* net = NULL;
+
+    if (!net)
+    {
+        net = g_object_new (KATZE_TYPE_NET, NULL);
+        /* Since this is a "singleton", keep an extra reference */
+        g_object_ref (net);
+    }
+    else
+        g_object_ref (net);
 
     return net;
 }
 
+/**
+ * katze_net_get_session:
+ *
+ * Retrieves the session of the net.
+ *
+ * Return value: a session, or %NULL
+ *
+ * Since: 0.1.3
+ **/
+gpointer
+katze_net_get_session (KatzeNet* net)
+{
+    g_return_val_if_fail (KATZE_IS_NET (net), NULL);
+
+    #if HAVE_LIBSOUP
+    return net->session;
+    #else
+    return NULL;
+    #endif
+}
+
 typedef struct
 {
     KatzeNet* net;
@@ -231,7 +264,7 @@ katze_net_finished_cb (SoupMessage*  msg,
 }
 #endif
 
-gboolean
+static gboolean
 katze_net_local_cb (KatzeNetPriv* priv)
 {
     KatzeNetRequest* request;
@@ -280,7 +313,7 @@ katze_net_local_cb (KatzeNetPriv* priv)
     return FALSE;
 }
 
-gboolean
+static gboolean
 katze_net_default_cb (KatzeNetPriv* priv)
 {
     KatzeNetRequest* request;
@@ -383,7 +416,8 @@ static void
 katze_net_icon_priv_free (KatzeNetIconPriv* priv)
 {
     g_free (priv->icon_file);
-    g_object_unref (priv->widget);
+    if (priv->widget)
+        g_object_unref (priv->widget);
     g_free (priv);
 }
 
@@ -454,8 +488,17 @@ katze_net_icon_transfer_cb (KatzeNetRequest*  request,
     }
 
     if (!pixbuf)
-        pixbuf = gtk_widget_render_icon (priv->widget,
-            GTK_STOCK_FILE, GTK_ICON_SIZE_MENU, NULL);
+    {
+        if (priv->widget)
+            pixbuf = gtk_widget_render_icon (priv->widget,
+                GTK_STOCK_FILE, GTK_ICON_SIZE_MENU, NULL);
+        else
+        {
+            priv->icon_cb (NULL, priv->user_data);
+            katze_net_icon_priv_free (priv);
+            return;
+        }
+    }
     gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &icon_width, &icon_height);
     pixbuf_scaled = gdk_pixbuf_scale_simple (pixbuf, icon_width, icon_height,
                                              GDK_INTERP_BILINEAR);
@@ -470,7 +513,7 @@ katze_net_icon_transfer_cb (KatzeNetRequest*  request,
  * @net: a #KatzeNet
  * @uri: an URI string, or %NULL
  * @icon_cb: function to call upon completion
- * @widget: a related #GtkWidget
+ * @widget: a related #GtkWidget, or %NULL
  * @user_data: data to pass to the callback
  *
  * Requests a transfer of an icon for @uri. This is
@@ -481,7 +524,9 @@ katze_net_icon_transfer_cb (KatzeNetRequest*  request,
  * the same over multiple requests, plus it may
  * be scaled to fit the menu icon size.
  *
- * The @widget is needed for theming information.
+ * Pass a valid #GtkWidget to @widget if you want
+ * a themed default icon in case of a missing icon,
+ * otherwise %NULL will be returned in that case.
  *
  * The caller is expected to use the returned icon
  * and update it if @icon_cb is called.
@@ -493,6 +538,10 @@ katze_net_icon_transfer_cb (KatzeNetRequest*  request,
  * Note that both the returned #GdkPixbuf and the
  * icon passed to @icon_cb are newly allocated and
  * the caller owns the reference.
+ *
+ * Since 0.1.2 @widget can be %NULL.
+ *
+ * Return value: a #GdkPixbuf, or %NULL
  **/
 GdkPixbuf*
 katze_net_load_icon (KatzeNet*      net,
@@ -510,10 +559,11 @@ katze_net_load_icon (KatzeNet*      net,
     GdkPixbuf* pixbuf_scaled;
 
     g_return_val_if_fail (KATZE_IS_NET (net), NULL);
-    g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+    g_return_val_if_fail (!widget || GTK_IS_WIDGET (widget), NULL);
 
     pixbuf = NULL;
-    if (uri && g_str_has_prefix (uri, "http://"))
+    if (uri && (g_str_has_prefix (uri, "http://") ||
+        g_str_has_prefix (uri, "https://")))
     {
         i = 8;
         while (uri[i] != '\0' && uri[i] != '/')
@@ -535,8 +585,8 @@ katze_net_load_icon (KatzeNet*      net,
             if (pixbuf)
                 g_object_ref (pixbuf);
         }
-        else if (g_file_test (icon_file, G_FILE_TEST_EXISTS))
-            pixbuf = gdk_pixbuf_new_from_file (icon_file, NULL);
+        else if ((pixbuf = gdk_pixbuf_new_from_file (icon_file, NULL)))
+            ;
         /* If the called doesn't provide an icon callback,
            we assume there is no interest in loading an un-cached icon. */
         else if (icon_cb)
@@ -545,7 +595,7 @@ katze_net_load_icon (KatzeNet*      net,
             priv->net = net;
             priv->icon_file = icon_file;
             priv->icon_cb = icon_cb;
-            priv->widget = g_object_ref (widget);
+            priv->widget = widget ? g_object_ref (widget) : NULL;
             priv->user_data = user_data;
 
             katze_net_load_uri (net, icon_uri,
@@ -556,8 +606,13 @@ katze_net_load_icon (KatzeNet*      net,
     }
 
     if (!pixbuf)
-        pixbuf = gtk_widget_render_icon (widget,
-            GTK_STOCK_FILE, GTK_ICON_SIZE_MENU, NULL);
+    {
+        if (widget)
+            pixbuf = gtk_widget_render_icon (widget,
+                GTK_STOCK_FILE, GTK_ICON_SIZE_MENU, NULL);
+        else
+            return NULL;
+    }
     gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &icon_width, &icon_height);
     pixbuf_scaled = gdk_pixbuf_scale_simple (pixbuf, icon_width, icon_height,
                                              GDK_INTERP_BILINEAR);
