@@ -12,12 +12,15 @@
 #ifndef __KATZE_H__
 #define __KATZE_H__
 
+#include "katze-http-auth.h"
+#include "katze-http-cookies.h"
 #include "katze-throbber.h"
 #include "katze-utils.h"
 #include "katze-item.h"
 #include "katze-list.h"
 #include "katze-array.h"
 #include "katze-arrayaction.h"
+#include "katze-separatoraction.h"
 #include "katze-net.h"
 
 #endif /* __KATZE_H__ */
