@@ -759,7 +759,7 @@ midori_history_add_items (void*  data,
                 {
                     parent = katze_array_new (KATZE_TYPE_ARRAY);
                     katze_item_set_added (KATZE_ITEM (parent), day);
-                    strftime (token, sizeof (token), "%Y-%m-%d",
+                    strftime (token, sizeof (token), "%x",
                           localtime ((time_t *)&date));
                     katze_item_set_token (KATZE_ITEM (parent), token);
                     katze_array_add_item (array, parent);
@@ -1354,10 +1354,7 @@ soup_session_constructed_cb (GObject* object)
     g_signal_connect (settings, "notify::ident-string",
         G_CALLBACK (soup_session_settings_notify_ident_string_cb), object);
 
-    /* Only add the Auth feature if WebKit didn't already */
-    if (!g_signal_has_handler_pending (session,
-        g_signal_lookup ("authenticate", SOUP_TYPE_SESSION), 0, FALSE))
-        soup_session_add_feature_by_type (session, KATZE_TYPE_HTTP_AUTH);
+    soup_session_add_feature_by_type (session, KATZE_TYPE_HTTP_AUTH);
     midori_soup_session_debug (session);
 
     feature = g_object_new (KATZE_TYPE_HTTP_COOKIES, NULL);
@@ -1717,7 +1714,7 @@ main (int    argc,
     {
         g_print (
           "%s %s\n\n"
-          "Copyright (c) 2007-2008 Christian Dywan\n\n"
+          "Copyright (c) 2007-2009 Christian Dywan\n\n"
           "%s\n"
           "\t%s\n\n"
           "%s\n"
