@@ -27,7 +27,6 @@ struct _MidoriApp
 {
     GObject parent_instance;
 
-    GList* browsers;
     MidoriBrowser* browser;
     GtkAccelGroup* accel_group;
 
@@ -37,6 +36,7 @@ struct _MidoriApp
     KatzeArray* search_engines;
     KatzeArray* history;
     KatzeArray* extensions;
+    KatzeArray* browsers;
 
     gpointer instance;
 };
@@ -65,6 +65,7 @@ enum
     PROP_SEARCH_ENGINES,
     PROP_HISTORY,
     PROP_EXTENSIONS,
+    PROP_BROWSERS,
     PROP_BROWSER,
     PROP_BROWSER_COUNT
 };
@@ -127,8 +128,8 @@ static gboolean
 midori_browser_destroy_cb (MidoriBrowser* browser,
                            MidoriApp*     app)
 {
-    app->browsers = g_list_remove (app->browsers, browser);
-    if (g_list_nth (app->browsers, 0))
+    katze_array_remove_item (app->browsers, browser);
+    if (!katze_array_is_empty (app->browsers))
         return FALSE;
     midori_app_quit (app);
     return TRUE;
@@ -157,10 +158,11 @@ _midori_app_add_browser (MidoriApp*     app,
         "signal::quit", midori_browser_quit_cb, app,
         NULL);
 
-    app->browsers = g_list_prepend (app->browsers, browser);
+    katze_array_add_item (app->browsers, browser);
 
     #if HAVE_UNIQUE
-    unique_app_watch_window (app->instance, GTK_WINDOW (browser));
+    if (app->instance)
+        unique_app_watch_window (app->instance, GTK_WINDOW (browser));
     #endif
 }
 
@@ -211,7 +213,7 @@ midori_app_class_init (MidoriAppClass* class)
                                      "Settings",
                                      "The associated settings",
                                      MIDORI_TYPE_WEB_SETTINGS,
-                                     G_PARAM_READWRITE));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property (gobject_class,
                                      PROP_BOOKMARKS,
@@ -220,7 +222,7 @@ midori_app_class_init (MidoriAppClass* class)
                                      "Bookmarks",
                                      "The bookmarks folder, containing all bookmarks",
                                      KATZE_TYPE_ARRAY,
-                                     G_PARAM_READWRITE));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property (gobject_class,
                                      PROP_TRASH,
@@ -229,7 +231,7 @@ midori_app_class_init (MidoriAppClass* class)
                                      "Trash",
                                      "The trash, collecting recently closed tabs and windows",
                                      KATZE_TYPE_ARRAY,
-                                     G_PARAM_READWRITE));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property (gobject_class,
                                      PROP_SEARCH_ENGINES,
@@ -238,7 +240,7 @@ midori_app_class_init (MidoriAppClass* class)
                                      "Search Engines",
                                      "The list of search engines",
                                      KATZE_TYPE_ARRAY,
-                                     G_PARAM_READWRITE));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property (gobject_class,
                                      PROP_HISTORY,
@@ -247,7 +249,7 @@ midori_app_class_init (MidoriAppClass* class)
                                      "History",
                                      "The list of history items",
                                      KATZE_TYPE_ARRAY,
-                                     G_PARAM_READWRITE));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property (gobject_class,
                                      PROP_EXTENSIONS,
@@ -256,8 +258,31 @@ midori_app_class_init (MidoriAppClass* class)
                                      "Extensions",
                                      "The list of extensions",
                                      KATZE_TYPE_ARRAY,
-                                     G_PARAM_READWRITE));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
+    /**
+    * MidoriApp:browsers:
+    *
+    * The list of browsers.
+    *
+    * Since: 0.1.3
+    */
+    g_object_class_install_property (gobject_class,
+                                     PROP_BROWSERS,
+                                     g_param_spec_object (
+                                     "browsers",
+                                     "Browsers",
+                                     "The list of browsers",
+                                     KATZE_TYPE_ARRAY,
+                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
+    /**
+    * MidoriApp:browser:
+    *
+    * The current browser, that is the one that was last used.
+    *
+    * Since: 0.1.3
+    */
     g_object_class_install_property (gobject_class,
                                      PROP_BROWSER,
                                      g_param_spec_object (
@@ -265,8 +290,15 @@ midori_app_class_init (MidoriAppClass* class)
                                      "Browser",
                                      "The current browser",
                                      MIDORI_TYPE_BROWSER,
-                                     G_PARAM_READABLE));
+                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
+    /**
+    * MidoriApp:browser-count:
+    *
+    * The number of browsers.
+    *
+    * Deprecated: 0.1.3 Use MidoriApp:browsers instead.
+    */
     g_object_class_install_property (gobject_class,
                                      PROP_BROWSER_COUNT,
                                      g_param_spec_uint (
@@ -274,7 +306,7 @@ midori_app_class_init (MidoriAppClass* class)
                                      "Browser Count",
                                      "The current number of browsers",
                                      0, G_MAXUINT, 0,
-                                     G_PARAM_READABLE));
+                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 }
 
 #if HAVE_UNIQUE
@@ -361,6 +393,7 @@ static void
 midori_app_init (MidoriApp* app)
 {
     #if HAVE_UNIQUE
+    GdkDisplay* display;
     gchar* display_name;
     gchar* instance_name;
     guint i, n;
@@ -374,9 +407,16 @@ midori_app_init (MidoriApp* app)
     app->search_engines = NULL;
     app->history = NULL;
     app->extensions = NULL;
+    app->browsers = katze_array_new (MIDORI_TYPE_BROWSER);
 
     #if HAVE_UNIQUE
-    display_name = g_strdup (gdk_display_get_name (gdk_display_get_default ()));
+    if (!(display = gdk_display_get_default ()))
+    {
+        app->instance = NULL;
+        return;
+    }
+
+    display_name = g_strdup (gdk_display_get_name (display));
     n = strlen (display_name);
     for (i = 0; i < n; i++)
         if (display_name[i] == ':' || display_name[i] == '.')
@@ -397,7 +437,6 @@ midori_app_finalize (GObject* object)
 {
     MidoriApp* app = MIDORI_APP (object);
 
-    g_list_free (app->browsers);
     g_object_unref (app->accel_group);
 
     katze_object_assign (app->settings, NULL);
@@ -406,6 +445,7 @@ midori_app_finalize (GObject* object)
     katze_object_assign (app->search_engines, NULL);
     katze_object_assign (app->history, NULL);
     katze_object_assign (app->extensions, NULL);
+    katze_object_assign (app->browsers, NULL);
 
     katze_object_assign (app->instance, NULL);
 
@@ -479,11 +519,14 @@ midori_app_get_property (GObject*    object,
     case PROP_EXTENSIONS:
         g_value_set_object (value, app->extensions);
         break;
+    case PROP_BROWSERS:
+        g_value_set_object (value, app->browsers);
+        break;
     case PROP_BROWSER:
         g_value_set_object (value, app->browser);
         break;
     case PROP_BROWSER_COUNT:
-        g_value_set_uint (value, g_list_length (app->browsers));
+        g_value_set_uint (value, katze_array_get_length (app->browsers));
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -527,10 +570,10 @@ midori_app_instance_is_running (MidoriApp* app)
     g_return_val_if_fail (MIDORI_IS_APP (app), FALSE);
 
     #if HAVE_UNIQUE
-    return unique_app_is_running (app->instance);
-    #else
-    return FALSE;
+    if (app->instance)
+        return unique_app_is_running (app->instance);
     #endif
+    return FALSE;
 }
 
 /**
@@ -555,9 +598,12 @@ midori_app_instance_send_activate (MidoriApp* app)
     g_return_val_if_fail (midori_app_instance_is_running (app), FALSE);
 
     #if HAVE_UNIQUE
-    response = unique_app_send_message (app->instance, UNIQUE_ACTIVATE, NULL);
-    if (response == UNIQUE_RESPONSE_OK)
-        return TRUE;
+    if (app->instance)
+    {
+        response = unique_app_send_message (app->instance, UNIQUE_ACTIVATE, NULL);
+        if (response == UNIQUE_RESPONSE_OK)
+            return TRUE;
+    }
     #endif
     return FALSE;
 }
@@ -582,9 +628,12 @@ midori_app_instance_send_new_browser (MidoriApp* app)
     g_return_val_if_fail (midori_app_instance_is_running (app), FALSE);
 
     #if HAVE_UNIQUE
-    response = unique_app_send_message (app->instance, UNIQUE_NEW, NULL);
-    if (response == UNIQUE_RESPONSE_OK)
-        return TRUE;
+    if (app->instance)
+    {
+        response = unique_app_send_message (app->instance, UNIQUE_NEW, NULL);
+        if (response == UNIQUE_RESPONSE_OK)
+            return TRUE;
+    }
     #endif
     return FALSE;
 }
@@ -615,12 +664,15 @@ midori_app_instance_send_uris (MidoriApp* app,
     g_return_val_if_fail (uris != NULL, FALSE);
 
     #if HAVE_UNIQUE
-    message = unique_message_data_new ();
-    unique_message_data_set_uris (message, uris);
-    response = unique_app_send_message (app->instance, UNIQUE_OPEN, message);
-    unique_message_data_free (message);
-    if (response == UNIQUE_RESPONSE_OK)
-        return TRUE;
+    if (app->instance)
+    {
+        message = unique_message_data_new ();
+        unique_message_data_set_uris (message, uris);
+        response = unique_app_send_message (app->instance, UNIQUE_OPEN, message);
+        unique_message_data_free (message);
+        if (response == UNIQUE_RESPONSE_OK)
+            return TRUE;
+    }
     #endif
     return FALSE;
 }
