@@ -67,6 +67,7 @@ struct _MidoriView
     gboolean open_tabs_in_the_background;
     gboolean close_buttons_on_tabs;
     MidoriNewPage open_new_pages_in;
+    gboolean find_while_typing;
 
     GtkWidget* menu_item;
     GtkWidget* tab_label;
@@ -817,7 +818,7 @@ gtk_widget_key_press_event_cb (WebKitWebView* web_view,
     if (character == (event->keyval | 0x01000000))
         return FALSE;
 
-    if (!webkit_web_view_can_cut_clipboard (web_view)
+    if (view->find_while_typing && !webkit_web_view_can_cut_clipboard (web_view)
         && !webkit_web_view_can_paste_clipboard (web_view))
     {
         gchar* text = g_strdup_printf ("%c", character);
@@ -1160,7 +1161,7 @@ webkit_web_view_mime_type_decision_cb (GtkWidget*      web_view,
         g_strrstr (mime_type, "script") ||
         g_str_has_prefix (mime_type, "text/") || g_strrstr (mime_type, "xml"))
     #endif
-        return TRUE;
+        return FALSE;
 
     #if WEBKIT_CHECK_VERSION (1, 0, 0)
     uri = g_strdup_printf ("error:nodisplay %s",
@@ -1365,6 +1366,7 @@ _midori_view_update_settings (MidoriView* view)
         "open-new-pages-in", &view->open_new_pages_in,
         "middle-click-opens-selection", &view->middle_click_opens_selection,
         "open-tabs-in-the-background", &view->open_tabs_in_the_background,
+        "find-while-typing", &view->find_while_typing,
         NULL);
 
     if (view->web_view)
@@ -1412,6 +1414,10 @@ midori_view_settings_notify_cb (MidoriWebSettings* settings,
     {
         view->open_tabs_in_the_background = g_value_get_boolean (&value);
     }
+    else if (name == g_intern_string ("find-while-typing"))
+    {
+        view->find_while_typing = g_value_get_boolean (&value);
+    }
 
     g_value_unset (&value);
 }
@@ -1602,10 +1608,14 @@ midori_view_construct_web_view (MidoriView* view)
                       webkit_web_frame_load_done_cb, view,
                       NULL);
 
-    g_object_set (view->web_view, "settings", view->settings, NULL);
-    if (katze_object_has_property (view->web_view, "full-content-zoom"))
-        g_object_set (view->web_view, "full-content-zoom",
-        katze_object_get_boolean (view->settings, "zoom-text-and-images"), NULL);
+    if (view->settings)
+    {
+        g_object_set (view->web_view, "settings", view->settings, NULL);
+        if (katze_object_has_property (view->web_view, "full-content-zoom"))
+            g_object_set (view->web_view, "full-content-zoom",
+                katze_object_get_boolean (view->settings,
+                                          "zoom-text-and-images"), NULL);
+    }
 
     gtk_widget_show (view->web_view);
     gtk_container_add (GTK_CONTAINER (view), view->web_view);
@@ -1681,9 +1691,9 @@ midori_view_set_uri (MidoriView*  view,
                     "<body><h1>%s</h1>"
                     "<img src=\"file://" DATADIR "/midori/logo-shade.png\" "
                     "style=\"position: absolute; right: 15px; bottom: 15px;\">"
-                    "<p />The document %s cannot be displayed."
+                    "<p />The document %s of type %s cannot be displayed."
                     "</body></html>",
-                    title, title, view->uri);
+                    title, title, view->uri, view->mime_type);
                 g_free (title);
             }
             else if (!strncmp (uri, "error:nodocs ", 13))
@@ -2525,10 +2535,27 @@ midori_view_execute_script (MidoriView*  view,
                             const gchar* script,
                             gchar**      exception)
 {
+    WebKitWebFrame* web_frame;
+    JSContextRef js_context;
+    #if HAVE_LIBSOUP
+    gchar* script_decoded;
+    #endif
+
     g_return_val_if_fail (MIDORI_IS_VIEW (view), FALSE);
     g_return_val_if_fail (script != NULL, FALSE);
 
     /* FIXME Actually store exception. */
-    webkit_web_view_execute_script (WEBKIT_WEB_VIEW (view->web_view), script);
+    web_frame = webkit_web_view_get_main_frame (WEBKIT_WEB_VIEW (view->web_view));
+    js_context = webkit_web_frame_get_global_context (web_frame);
+    #if HAVE_LIBSOUP
+    if ((script_decoded = soup_uri_decode (script)))
+    {
+        webkit_web_view_execute_script (WEBKIT_WEB_VIEW (view->web_view),
+                                        script_decoded);
+        g_free (script_decoded);
+    }
+    else
+    #endif
+        webkit_web_view_execute_script (WEBKIT_WEB_VIEW (view->web_view), script);
     return TRUE;
 }
