@@ -16,6 +16,13 @@
 
 #include <gtk/gtk.h>
 
+#include <JavaScriptCore/JavaScript.h>
+
+JSValueRef
+sokoke_js_script_eval (JSContextRef js_context,
+                       const gchar* script,
+                       gchar**      exception);
+
 /* Many themes need this hack for small toolbars to work */
 #define GTK_ICON_SIZE_SMALL_TOOLBAR GTK_ICON_SIZE_BUTTON
 
@@ -114,17 +121,10 @@ sokoke_action_create_popup_menu_item (GtkAction*     action);
 GtkWidget*
 sokoke_image_menu_item_new_ellipsized (const gchar*  label);
 
-gboolean
-sokoke_tree_view_get_selected_iter   (GtkTreeView*   tree_view,
-                                      GtkTreeModel** model,
-                                      GtkTreeIter*   iter);
+gint64
+sokoke_time_t_to_julian              (const time_t*  timestamp);
 
-gboolean
-sokoke_same_day                      (const time_t*  day1,
-                                      const time_t*  day2);
-
-gint
-sokoke_days_between                  (const time_t*  day1,
-                                      const time_t*  day2);
+void
+sokoke_register_stock_items          (void);
 
 #endif /* !__SOKOKE_H__ */
